@@ -1,5 +1,6 @@
 import re
 from io import StringIO
+from typing import Any, Dict
 
 import isort
 import pytest
@@ -10,6 +11,24 @@ from pytest_logikal.file_checker import CachedFileCheckItem, CachedFileCheckPlug
 from pytest_logikal.plugin import ItemRunError
 
 
+def get_config(max_line_length: int) -> Dict[str, Any]:
+    config = {
+        'py_version': 'auto',
+        'line_length': max_line_length,
+        'multi_line_output': WrapModes.VERTICAL_GRID_GROUPED,  # type: ignore[attr-defined]
+        'balanced_wrapping': True,
+        'combine_as_imports': True,
+        'use_parentheses': True,
+        'include_trailing_comma': True,
+        'color_output': True,
+    }
+    if 'tool' in PYPROJECT and 'isort' in PYPROJECT['tool']:
+        for option in config:
+            if option in PYPROJECT['tool']['isort']:
+                config[option] = PYPROJECT['tool']['isort'][option]
+    return config
+
+
 def pytest_addoption(parser: pytest.Parser) -> None:
     group = parser.getgroup('isort')
     group.addoption('--isort', action='store_true', default=False, help='run isort')
@@ -23,21 +42,7 @@ def pytest_configure(config: pytest.Config) -> None:
 
 class IsortItem(CachedFileCheckItem):
     def run(self) -> None:
-        config = {
-            'py_version': 'auto',
-            'line_length': int(self.config.getini('max_line_length')),
-            'multi_line_output': WrapModes.VERTICAL_GRID_GROUPED,  # type: ignore[attr-defined]
-            'balanced_wrapping': True,
-            'combine_as_imports': True,
-            'use_parentheses': True,
-            'include_trailing_comma': True,
-            'color_output': True,
-        }
-        if 'tool' in PYPROJECT and 'isort' in PYPROJECT['tool']:
-            for option in config:
-                if option in PYPROJECT['tool']['isort']:
-                    config[option] = PYPROJECT['tool']['isort'][option]
-
+        config = get_config(max_line_length=int(self.config.getini('max_line_length')))
         stdout = StringIO()
         if not isort.check_file(filename=str(self.path), show_diff=stdout, **config):
             diff = stdout.getvalue()
